@@ -8,20 +8,27 @@ pub fn app() -> App<'static> {
             Arg::new("address")
                 .index(1)
                 .takes_value(true)
-                // .required(true)
                 .help("A task address"),
         )
 }
 
 fn task_new_app() -> App<'static> {
     App::new("new")
-        .about("Schedule a new task")
+        .about("Creates a new task")
+        .arg(
+            Arg::new("filepath")
+                // .index(1)
+                .long("filepath")
+                .short('f')
+                .required(true)
+                .takes_value(true)
+                .help("Filepath to the instruction to invoke"),
+        )
         .arg(
             Arg::new("exec_at")
                 .long("exec_at")
                 .short('e')
                 .required(false)
-                .global(true)
                 .help("When to invoke the instruction"),
         )
         .arg(
@@ -29,7 +36,6 @@ fn task_new_app() -> App<'static> {
                 .long("stop_at")
                 .short('s')
                 .required(false)
-                .global(true)
                 .help("When to stop invoke the instruction"),
         )
         .arg(
@@ -37,7 +43,6 @@ fn task_new_app() -> App<'static> {
                 .long("recurr")
                 .short('r')
                 .required(false)
-                .global(true)
                 .help("The duration to wait between instruction invocations"),
         )
 }
