@@ -19,11 +19,23 @@ pub fn process(matches: &ArgMatches) -> Result<(), CliError> {
     let client = Arc::new(Client { client, payer });
 
     match command {
+        CliCommand::AdminCancelTask { address } => super::admin::cancel_task(&client, &address),
+        CliCommand::AdminScheduleHealthCheck => super::admin::schedule_health_check(&client),
         CliCommand::Blocktime => super::blocktime::get(&client),
+        CliCommand::ConfigGet => super::config::get(&client),
+        CliCommand::ConfigSetMinRecurr { new_value } => {
+            super::config::set_min_recurr(&client, &new_value)
+        }
+        CliCommand::ConfigSetProgramFee { new_value } => {
+            super::config::set_program_fee(&client, &new_value)
+        }
+        CliCommand::ConfigSetWorkerFee { new_value } => {
+            super::config::set_worker_fee(&client, &new_value)
+        }
         CliCommand::DaemonNew => super::daemon::new(&client),
-        CliCommand::DaemonData => super::daemon::data(&client),
-        CliCommand::HealthCheck => super::health::check(&client),
-        CliCommand::TaskData { address } => super::task::data(&client, &address),
+        CliCommand::DaemonData => super::daemon::get(&client),
+        CliCommand::HealthGet => super::health::get(&client),
+        CliCommand::TaskData { address } => super::task::get(&client, &address),
         CliCommand::TaskNew {
             exec_at,
             stop_at,
